==> weblinks-1.1.0.tar.gz: weblinks-1.1.0/README.md <==
# Weblinks

[![License: Apache 2.0](https://img.shields.io/badge/License-Apache2-yellow.svg)](https://opensource.org/licenses/Apache-2.0)
[![Version: 1.1](https://img.shields.io/badge/Version-1.1-parrotgreen.svg)](https://github.com/kirankotari/weblinks)
[![Downloads](https://pepy.tech/badge/weblinks)](https://pepy.tech/project/weblinks)
[![Downloads](https://pepy.tech/badge/weblinks/week)](https://pepy.tech/project/weblinks/week)

- [Introduction](#introduction)
- [Installation and Downloads](#installation-and-downloads)
- [Usage](#usage)
- [License and Copyright](#license-and-copyright)
- [Author and Thanks](#author-and-thanks)

## Introduction

Wanted to fetch the links from web and filter them using substring, a file extentions

## Installation and Downloads

`pip install weblinks`

## Usage

```
usage: weblinks.py [-h] -w WEB [-u USERNAME] [-p PASSWORD] [-e EXT] [-d] [-v]
                   substring

positional arguments:
  substring             the sub-string in the links

optional arguments:
  -h, --help            show this help message and exit
  -w WEB, --web WEB     the website
  -u USERNAME, --username USERNAME
                        web login username
  -p PASSWORD, --password PASSWORD
                        web login password
  -e EXT, --ext EXT     file extention
  -d, --download        download links
  -v, --verbosity
```

## License and Copyright

- weblinks is licensed [Apache 2.0](https://opensource.org/licenses/Apache-2.0) 2022

## Author and Thanks

Weblinks was developed by [Kiran Kumar Kotari](https://github.com/kirankotari)

==> weblinks-1.1.1.tar.gz: weblinks-1.1.1/README.md <==
# Weblinks

[![License: Apache 2.0](https://img.shields.io/badge/License-Apache2-yellow.svg)](https://opensource.org/licenses/Apache-2.0)
[![Version: 1.1](https://img.shields.io/badge/Version-1.1-parrotgreen.svg)](https://github.com/kirankotari/weblinks)
[![Downloads](https://pepy.tech/badge/weblinks)](https://pepy.tech/project/weblinks)
[![Downloads](https://pepy.tech/badge/weblinks/week)](https://pepy.tech/project/weblinks/week)

- [Introduction](#introduction)
- [Installation and Downloads](#installation-and-downloads)
- [Usage](#usage)
- [License and Copyright](#license-and-copyright)
- [Author and Thanks](#author-and-thanks)

## Introduction

Wanted to fetch the links from web and filter them using substring, a file extentions

## Installation and Downloads

`pip install weblinks`

## Usage

```
usage: weblinks [-h] -w WEB [-u USERNAME] [-p PASSWORD] [-e EXT] [-d] [-v]
                   substring

positional arguments:
  substring             the sub-string in the links

optional arguments:
  -h, --help            show this help message and exit
  -w WEB, --web WEB     the website
  -u USERNAME, --username USERNAME
                        web login username
  -p PASSWORD, --password PASSWORD
                        web login password
  -e EXT, --ext EXT     file extention
  -d, --download        download links
  -v, --verbosity
```

## License and Copyright

- weblinks is licensed [Apache 2.0](https://opensource.org/licenses/Apache-2.0) 2022

## Author and Thanks

Weblinks was developed by [Kiran Kumar Kotari](https://github.com/kirankotari)
